# pymisclib
A collection of various useful Python routines.

## Authors
[Christian Dönges](https://rot.regenbogenkraut.de/cd/)


## Documentation

Documentation is available at https://pymisclib.readthedocs.io/en/latest/.

Assuming that you have [Sphinx](https://www.sphinx-doc.org/) installed, you can build it yourself:

```bash
cd docs
make html
```

The documentation is created at _docs/\_build/html_.


## Installation
Install pymisclib using `pip`:

```bash
python -m pip install pymisclib
```

On Debian and possibly other systems, you may have to use

```bash
python3 -m pip install pymisclib
```

## Requirements
* Python 3.9 or later. Python 3.10 recommended.


## LICENSE
© Copyright 2012-2022, 2023, 2024 by Christian Dönges <cd.pymisclib@platypus-projects.net>

Licensed under the Apache License, Version 2.0 (the "License"); you may
not use this file except in compliance with the License. You may obtain a
copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.


If you need another license, contact the author to discuss terms.


## ANSI Support
The supported ANSI features of various terminals are listed in the
*ansiterminal* documentation.
